/****************************************************************************
** Meta object code from reading C++ file 'majorimageprocessingthread.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/majorimageprocessingthread.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'majorimageprocessingthread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MajorImageProcessingThread_t {
    QByteArrayData data[20];
    char stringdata0[243];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MajorImageProcessingThread_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MajorImageProcessingThread_t qt_meta_stringdata_MajorImageProcessingThread = {
    {
QT_MOC_LITERAL(0, 0, 26), // "MajorImageProcessingThread"
QT_MOC_LITERAL(1, 27, 24), // "SendMajorImageProcessing"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 7), // "QImage*"
QT_MOC_LITERAL(4, 61, 5), // "image"
QT_MOC_LITERAL(5, 67, 6), // "result"
QT_MOC_LITERAL(6, 74, 25), // "SendFilterImageProcessing"
QT_MOC_LITERAL(7, 100, 23), // "sigReflushSnapshotLabel"
QT_MOC_LITERAL(8, 124, 11), // "sigYUVFrame"
QT_MOC_LITERAL(9, 136, 6), // "uchar*"
QT_MOC_LITERAL(10, 143, 3), // "yuv"
QT_MOC_LITERAL(11, 147, 5), // "width"
QT_MOC_LITERAL(12, 153, 6), // "height"
QT_MOC_LITERAL(13, 160, 12), // "sigRenderYuv"
QT_MOC_LITERAL(14, 173, 14), // "sigRecordFrame"
QT_MOC_LITERAL(15, 188, 3), // "rgb"
QT_MOC_LITERAL(16, 192, 4), // "size"
QT_MOC_LITERAL(17, 197, 21), // "reachMaxDelayedFrames"
QT_MOC_LITERAL(18, 219, 15), // "processingImage"
QT_MOC_LITERAL(19, 235, 7) // "QImage&"

    },
    "MajorImageProcessingThread\0"
    "SendMajorImageProcessing\0\0QImage*\0"
    "image\0result\0SendFilterImageProcessing\0"
    "sigReflushSnapshotLabel\0sigYUVFrame\0"
    "uchar*\0yuv\0width\0height\0sigRenderYuv\0"
    "sigRecordFrame\0rgb\0size\0reachMaxDelayedFrames\0"
    "processingImage\0QImage&"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MajorImageProcessingThread[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   54,    2, 0x06 /* Public */,
       6,    1,   59,    2, 0x06 /* Public */,
       7,    0,   62,    2, 0x06 /* Public */,
       8,    3,   63,    2, 0x06 /* Public */,
      13,    1,   70,    2, 0x06 /* Public */,
      14,    2,   73,    2, 0x06 /* Public */,
      17,    0,   78,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      18,    1,   79,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9, QMetaType::UInt, QMetaType::UInt,   10,   11,   12,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 9, QMetaType::UInt,   15,   16,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 19,    2,

       0        // eod
};

void MajorImageProcessingThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MajorImageProcessingThread *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->SendMajorImageProcessing((*reinterpret_cast< QImage*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->SendFilterImageProcessing((*reinterpret_cast< QImage*(*)>(_a[1]))); break;
        case 2: _t->sigReflushSnapshotLabel(); break;
        case 3: _t->sigYUVFrame((*reinterpret_cast< uchar*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 4: _t->sigRenderYuv((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->sigRecordFrame((*reinterpret_cast< uchar*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 6: _t->reachMaxDelayedFrames(); break;
        case 7: _t->processingImage((*reinterpret_cast< QImage(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MajorImageProcessingThread::*)(QImage * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MajorImageProcessingThread::SendMajorImageProcessing)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MajorImageProcessingThread::*)(QImage * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MajorImageProcessingThread::SendFilterImageProcessing)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (MajorImageProcessingThread::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MajorImageProcessingThread::sigReflushSnapshotLabel)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (MajorImageProcessingThread::*)(uchar * , uint , uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MajorImageProcessingThread::sigYUVFrame)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (MajorImageProcessingThread::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MajorImageProcessingThread::sigRenderYuv)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (MajorImageProcessingThread::*)(uchar * , uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MajorImageProcessingThread::sigRecordFrame)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (MajorImageProcessingThread::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MajorImageProcessingThread::reachMaxDelayedFrames)) {
                *result = 6;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MajorImageProcessingThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_meta_stringdata_MajorImageProcessingThread.data,
    qt_meta_data_MajorImageProcessingThread,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MajorImageProcessingThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MajorImageProcessingThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MajorImageProcessingThread.stringdata0))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int MajorImageProcessingThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void MajorImageProcessingThread::SendMajorImageProcessing(QImage * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MajorImageProcessingThread::SendFilterImageProcessing(QImage * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void MajorImageProcessingThread::sigReflushSnapshotLabel()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MajorImageProcessingThread::sigYUVFrame(uchar * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void MajorImageProcessingThread::sigRenderYuv(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void MajorImageProcessingThread::sigRecordFrame(uchar * _t1, uint _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void MajorImageProcessingThread::reachMaxDelayedFrames()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
