/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CMainWindow_t {
    QByteArrayData data[48];
    char stringdata0[689];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CMainWindow_t qt_meta_stringdata_CMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 11), // "CMainWindow"
QT_MOC_LITERAL(1, 12, 13), // "setSelBtnHide"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 18), // "onLocalTimeChanged"
QT_MOC_LITERAL(4, 46, 13), // "setSelBtnShow"
QT_MOC_LITERAL(5, 60, 18), // "onSettingsDlgClose"
QT_MOC_LITERAL(6, 79, 16), // "onEnableSettings"
QT_MOC_LITERAL(7, 96, 5), // "bTrue"
QT_MOC_LITERAL(8, 102, 13), // "onTakePicDone"
QT_MOC_LITERAL(9, 116, 13), // "onTakePicOnce"
QT_MOC_LITERAL(10, 130, 15), // "onTakePicCancel"
QT_MOC_LITERAL(11, 146, 12), // "onTakeVdDone"
QT_MOC_LITERAL(12, 159, 14), // "onTakeVdCancel"
QT_MOC_LITERAL(13, 174, 17), // "updateBlockSystem"
QT_MOC_LITERAL(14, 192, 7), // "onNoCam"
QT_MOC_LITERAL(15, 200, 29), // "stopCancelContinuousRecording"
QT_MOC_LITERAL(16, 230, 18), // "onDirectoryChanged"
QT_MOC_LITERAL(17, 249, 8), // "filePath"
QT_MOC_LITERAL(18, 258, 21), // "onSwitchCameraSuccess"
QT_MOC_LITERAL(19, 280, 10), // "cameraName"
QT_MOC_LITERAL(20, 291, 13), // "onTimeoutLock"
QT_MOC_LITERAL(21, 305, 11), // "onTrashFile"
QT_MOC_LITERAL(22, 317, 8), // "fileName"
QT_MOC_LITERAL(23, 326, 21), // "onSwitchPhotoBtnClked"
QT_MOC_LITERAL(24, 348, 22), // "onSwitchRecordBtnClked"
QT_MOC_LITERAL(25, 371, 27), // "onModeSwitchBoxValueChanged"
QT_MOC_LITERAL(26, 399, 21), // "onPhotoRecordBtnClked"
QT_MOC_LITERAL(27, 421, 21), // "onShowCameraNameTimer"
QT_MOC_LITERAL(28, 443, 19), // "onUpdateRecordState"
QT_MOC_LITERAL(29, 463, 5), // "state"
QT_MOC_LITERAL(30, 469, 18), // "onUpdatePhotoState"
QT_MOC_LITERAL(31, 488, 20), // "onStopPhotoAndRecord"
QT_MOC_LITERAL(32, 509, 20), // "onMirrorStateChanged"
QT_MOC_LITERAL(33, 530, 7), // "bMirror"
QT_MOC_LITERAL(34, 538, 10), // "onSetFlash"
QT_MOC_LITERAL(35, 549, 8), // "bFlashOn"
QT_MOC_LITERAL(36, 558, 7), // "onKeyUp"
QT_MOC_LITERAL(37, 566, 9), // "onKeyDown"
QT_MOC_LITERAL(38, 576, 9), // "onKeyLeft"
QT_MOC_LITERAL(39, 586, 10), // "onkeyRight"
QT_MOC_LITERAL(40, 597, 15), // "onFilterChanged"
QT_MOC_LITERAL(41, 613, 11), // "efilterType"
QT_MOC_LITERAL(42, 625, 4), // "type"
QT_MOC_LITERAL(43, 630, 16), // "onShowFilterName"
QT_MOC_LITERAL(44, 647, 5), // "bShow"
QT_MOC_LITERAL(45, 653, 15), // "onSetFilterName"
QT_MOC_LITERAL(46, 669, 4), // "name"
QT_MOC_LITERAL(47, 674, 14) // "updateSizeMode"

    },
    "CMainWindow\0setSelBtnHide\0\0"
    "onLocalTimeChanged\0setSelBtnShow\0"
    "onSettingsDlgClose\0onEnableSettings\0"
    "bTrue\0onTakePicDone\0onTakePicOnce\0"
    "onTakePicCancel\0onTakeVdDone\0"
    "onTakeVdCancel\0updateBlockSystem\0"
    "onNoCam\0stopCancelContinuousRecording\0"
    "onDirectoryChanged\0filePath\0"
    "onSwitchCameraSuccess\0cameraName\0"
    "onTimeoutLock\0onTrashFile\0fileName\0"
    "onSwitchPhotoBtnClked\0onSwitchRecordBtnClked\0"
    "onModeSwitchBoxValueChanged\0"
    "onPhotoRecordBtnClked\0onShowCameraNameTimer\0"
    "onUpdateRecordState\0state\0onUpdatePhotoState\0"
    "onStopPhotoAndRecord\0onMirrorStateChanged\0"
    "bMirror\0onSetFlash\0bFlashOn\0onKeyUp\0"
    "onKeyDown\0onKeyLeft\0onkeyRight\0"
    "onFilterChanged\0efilterType\0type\0"
    "onShowFilterName\0bShow\0onSetFilterName\0"
    "name\0updateSizeMode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CMainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  189,    2, 0x08 /* Private */,
       3,    0,  190,    2, 0x08 /* Private */,
       4,    0,  191,    2, 0x08 /* Private */,
       5,    0,  192,    2, 0x08 /* Private */,
       6,    1,  193,    2, 0x08 /* Private */,
       8,    0,  196,    2, 0x08 /* Private */,
       9,    0,  197,    2, 0x08 /* Private */,
      10,    0,  198,    2, 0x08 /* Private */,
      11,    0,  199,    2, 0x08 /* Private */,
      12,    0,  200,    2, 0x08 /* Private */,
      13,    1,  201,    2, 0x08 /* Private */,
      14,    0,  204,    2, 0x08 /* Private */,
      15,    1,  205,    2, 0x08 /* Private */,
      16,    1,  208,    2, 0x08 /* Private */,
      18,    1,  211,    2, 0x08 /* Private */,
      20,    3,  214,    2, 0x08 /* Private */,
      21,    1,  221,    2, 0x08 /* Private */,
      23,    0,  224,    2, 0x08 /* Private */,
      24,    0,  225,    2, 0x08 /* Private */,
      25,    1,  226,    2, 0x08 /* Private */,
      26,    0,  229,    2, 0x08 /* Private */,
      27,    0,  230,    2, 0x08 /* Private */,
      28,    1,  231,    2, 0x08 /* Private */,
      30,    1,  234,    2, 0x08 /* Private */,
      31,    0,  237,    2, 0x08 /* Private */,
      32,    1,  238,    2, 0x08 /* Private */,
      34,    1,  241,    2, 0x08 /* Private */,
      36,    0,  244,    2, 0x08 /* Private */,
      37,    0,  245,    2, 0x08 /* Private */,
      38,    0,  246,    2, 0x08 /* Private */,
      39,    0,  247,    2, 0x08 /* Private */,
      40,    1,  248,    2, 0x08 /* Private */,
      43,    1,  251,    2, 0x08 /* Private */,
      45,    1,  254,    2, 0x08 /* Private */,
      47,    0,  257,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::QString,   19,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QStringList,    2,    2,    2,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void, QMetaType::Int,   29,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   33,
    QMetaType::Void, QMetaType::Bool,   35,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 41,   42,
    QMetaType::Void, QMetaType::Bool,   44,
    QMetaType::Void, QMetaType::QString,   46,
    QMetaType::Void,

       0        // eod
};

void CMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CMainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setSelBtnHide(); break;
        case 1: _t->onLocalTimeChanged(); break;
        case 2: _t->setSelBtnShow(); break;
        case 3: _t->onSettingsDlgClose(); break;
        case 4: _t->onEnableSettings((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->onTakePicDone(); break;
        case 6: _t->onTakePicOnce(); break;
        case 7: _t->onTakePicCancel(); break;
        case 8: _t->onTakeVdDone(); break;
        case 9: _t->onTakeVdCancel(); break;
        case 10: _t->updateBlockSystem((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->onNoCam(); break;
        case 12: _t->stopCancelContinuousRecording((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->onDirectoryChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->onSwitchCameraSuccess((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->onTimeoutLock((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QVariantMap(*)>(_a[2])),(*reinterpret_cast< QStringList(*)>(_a[3]))); break;
        case 16: _t->onTrashFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->onSwitchPhotoBtnClked(); break;
        case 18: _t->onSwitchRecordBtnClked(); break;
        case 19: _t->onModeSwitchBoxValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->onPhotoRecordBtnClked(); break;
        case 21: _t->onShowCameraNameTimer(); break;
        case 22: _t->onUpdateRecordState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->onUpdatePhotoState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->onStopPhotoAndRecord(); break;
        case 25: _t->onMirrorStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->onSetFlash((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->onKeyUp(); break;
        case 28: _t->onKeyDown(); break;
        case 29: _t->onKeyLeft(); break;
        case 30: _t->onkeyRight(); break;
        case 31: _t->onFilterChanged((*reinterpret_cast< efilterType(*)>(_a[1]))); break;
        case 32: _t->onShowFilterName((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->onSetFilterName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 34: _t->updateSizeMode(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<DMainWindow::staticMetaObject>(),
    qt_meta_stringdata_CMainWindow.data,
    qt_meta_data_CMainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CMainWindow.stringdata0))
        return static_cast<void*>(this);
    return DMainWindow::qt_metacast(_clname);
}

int CMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 35;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
